# Copyright (c) 2004 Anton Kozyr. All rights reserved.
# See also LICENSE.txt

# python
import sys, string

# zope
from OFS import SimpleItem
from AccessControl import ClassSecurityInfo
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
import Globals, zLOG, urllib

_ViewManagementScreens = 'View management screens'

class Generator(SimpleItem.SimpleItem):
    """Implementation of an object which is configurable both
    manually and programmatically and can be called like a script returning
    the configured value.
    """
    
    meta_type = 'Generator Object'
    
    security = ClassSecurityInfo()
    
    manage_options = (
        {'label':'Edit', 'action':'manage_editForm', 'help':('Generator', 'howto.txt')},
        {'label':'Increment', 'action':'manage_increment', 'help':('Generator', 'howto.txt')},
        ) + SimpleItem.SimpleItem.manage_options

    security.declareProtected(_ViewManagementScreens, 'manage_editForm')
    manage_editForm = PageTemplateFile(
        'www/GeneratorEdit', globals(),  __name__='manage_editForm')

    security.declareProtected(_ViewManagementScreens, 'manage_main')
    manage_main = manage_editForm
    
    def __init__(self, id, title):
        self.id = id
        self.title = title
        self._value = 0
        self._comment = ''
    
    security.declareProtected(_ViewManagementScreens, 'edit_form')
    edit_form = manage_editForm

    security.declareProtected(_ViewManagementScreens, 'value')
    def value(self):
        """Returns the value stored by this Generator Object."""
        return self._value
 
    security.declareProtected(_ViewManagementScreens, 'set')
    def set(self, value):
        """Sets the value to be stored by this Generator Object."""
        self._value = value

    security.declareProtected(_ViewManagementScreens, 'inc')
    def inc(self):
        """Increments the value to be stored by this Generator Object."""
        self._value = self._value + 1
        return self._value
    
    security.declareProtected(_ViewManagementScreens, 'set_comment')
    def set_comment(self, comment):
        """Sets the comment explaining the property managed by this Generator Object."""
        self._comment = comment

    security.declareProtected(_ViewManagementScreens, 'comment')
    def comment(self):
        """Returns the comment explaining the property managed by this Generator Object."""
        return self._comment
    
    def __call__(self, *args, **kw):
        """Call the Generator. The same as increment.
        """
        return self.inc()

    security.declareProtected(_ViewManagementScreens, 'manage_edit')
    def manage_edit(self, REQUEST, redisplay=1):
        """Manage method to update title, comment and the value stored by this Generator Object."""
        self.set(REQUEST['value'])
        self.set_comment(REQUEST['comment'])
        self.title = REQUEST['title']
        if redisplay:
            return self.manage_main(manage_tabs_message="Value changed.")

    security.declareProtected(_ViewManagementScreens, 'manage_increment')
    def manage_increment(self, REQUEST, redisplay=1):
        """Manage method to update title, comment and the value stored by this Generator Object."""
        self.inc()
        if redisplay:
            return self.manage_main(manage_tabs_message="Value incremented.")
    
Globals.InitializeClass(Generator)

manage_addGeneratorForm = PageTemplateFile(
    "www/GeneratorAdd", globals(),
    __name__='manage_addGeneratorForm')

def manage_addGenerator(self, id, title='', REQUEST=None):
    """Add an instance of Generator."""
    object = Generator(id, title)
    self._setObject(id, object)
    object = getattr(self, id)
    if REQUEST is None:
        return
    try:
        u = self.DestinationURL()
    except:
        u = REQUEST['URL1']
    if REQUEST.has_key('submit_edit'):
        u = "%s/%s" % (u, urllib.quote(id))
    REQUEST.RESPONSE.redirect(u+'/manage_main')
    return ''

